==> glog-1.00.tar.gz: glog-1.00/index.xml.php <==
<?php
# RSS 2.0 exporter
#
# $Id: index.xml.php,v 1.2 2004/03/11 14:45:16 gf Exp $
#
# Copyright (c) 2004 Georgi Chorbadzhiyski
# All rights reserved.
#
# Redistribution and use of this script, with or without modification, is
# permitted provided that the following conditions are met:
#
# 1. Redistributions of this script must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
#  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
#  EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
#  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
#  ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
	define('PROGRAM', 1);
	include("funcs.php");
	header("Content-type: text/xml; charset=windows-1251");
	print '<' . '?xml version="1.0" encoding="windows-1251"?>';
?>
<rss version="2.0"
	xmlns:dc="http://purl.org/dc/elements/1.1/"
	xmlns:sy="http://purl.org/rss/1.0/modules/syndication/"
	xmlns:admin="http://webns.net/mvcb/"
	xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">

<channel>
	<title><?=BLOG_TITLE?></title>
	<link>http://<?=HOST?><?=BASEDIR?></link>
	<description><?=BLOG_TITLE?></description>
	<dc:language>bg</dc:language>
	<dc:creator><?=AUTHOR_EMAIL?></dc:creator>
	<sy:updatePeriod>daily</sy:updatePeriod>
	<sy:updateFrequency>1</sy:updateFrequency>
<?	if (count($days) > 0) {
		$stat = stat(get_filename(reset($days)));
?>
	<dc:date><?=date("r", $stat[10])?></dc:date>
<?	} ?>

<?
	if (count($days) > 0) {
		$i = 0;
		foreach ($days as $tmp => $date) {
			$text = format_day(implode('', file(get_filename($date))));
?>
	<item rdf:about="http://<?=HOST?><?=BASEDIR?>archive.php/<?=$date?>">
		<title><?=$date?></title>
		<link>http://<?=HOST?><?=BASEDIR?>archive.php/<?=$date?></link>
		<description><?=$text?></p></description>
		<dc:creator><?=AUTHOR?></dc:creator>
		<dc:date><?=$date?></dc:date>
	</item>
<?
			$i++;
			if ($i > 15)
				break;
		}
	}
?>
</channel>
</rss>

==> glog-2.00.tar.gz: glog-2.00/index.xml.php <==
<?php
# RSS 2.0 exporter
#
# $Id: index.xml.php,v 1.8 2004/09/06 15:31:09 gf Exp $
#
# Copyright (c) 2004 Georgi Chorbadzhiyski
# All rights reserved.
#
# Redistribution and use of this script, with or without modification, is
# permitted provided that the following conditions are met:
#
# 1. Redistributions of this script must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
#  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
#  EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
#  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
#  ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
	define('PROGRAM', 1);
	include("funcs.php");
	header("Content-type: text/xml; charset=windows-1251");
	print '<' . '?xml version="1.0" encoding="windows-1251"?>';
?>
<rss version="2.0" 
	xmlns:content="http://purl.org/rss/1.0/modules/content/">

<channel>
	<title><?=BLOG_TITLE?></title>
	<link>http://<?=HOST?><?=BASEDIR?></link>
	<description><?=BLOG_TITLE?></description>
	<language>bg</language>
	<copyright>Copyright (c) <?=AUTHOR_EMAIL?></copyright>
	<generator>http://georgi.unixsol.org/programs/glog/</generator>
<?	if (count($days) > 0) {
		$stat = stat(get_filename(reset($days)));
?>
	<pubDate><?=date("r", $stat[10])?></pubDate>
<?	} ?>

<?
	if (count($days) > 0) {
		$i = 0;
		foreach ($days as $tmp => $date) {
			$text = format_day(implode('', file(get_filename($date))));
?>
	<item>
		<title><?=ereg_replace(" 0"," ",date("l, dS of M Y",strtotime($date)))?></title>
		<link>http://<?=HOST?><?=BASEDIR?>archive.php/<?=$date?></link>
		<pubDate><?
			$stat = stat(get_filename($date));
			print date("r",$stat[9]);
		?></pubDate>
		<category></category>
		<guid isPermaLink="true">http://<?=HOST?><?=BASEDIR?>archive.php/<?=$date?></guid>
		<description><![CDATA[ <?=$text?></p> ]]></description>
		<content:encoded><![CDATA[ <?=$text?></p> ]]></content:encoded>
		<author><?=AUTHOR_EMAIL?> (<?=AUTHOR?>)</author>
	</item>
<?
			$i++;
			if ($i > FEEDS_ARTICLES)
				break;
		}
	}
?>
</channel>
</rss>
